@@ -19,6 +19,7 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     ResourceOwnerType,
+    ResourceRegionScopeFilterType,
     ResourceShareAssociationStatusType,
     ResourceShareAssociationTypeType,
     ResourceShareStatusType,
@@ -47,6 +48,7 @@ from .type_defs import (
     GetResourceSharesResponseTypeDef,
     ListPendingInvitationResourcesResponseTypeDef,
     ListPermissionsResponseTypeDef,
+    ListPermissionVersionsResponseTypeDef,
     ListPrincipalsResponseTypeDef,
     ListResourceSharePermissionsResponseTypeDef,
     ListResourcesResponseTypeDef,
@@ -97,12 +99,13 @@ class Exceptions:
     ServiceUnavailableException: Type[BotocoreClientError]
     TagLimitExceededException: Type[BotocoreClientError]
     TagPolicyViolationException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
     UnknownResourceException: Type[BotocoreClientError]
 
 
 class RAMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
     """
 
@@ -121,7 +124,7 @@ class RAMClient(BaseClient):
         Accepts an invitation to a resource share from another Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#accept_resource_share_invitation)
         """
 
@@ -134,10 +137,9 @@ class RAMClient(BaseClient):
         clientToken: str = ...
     ) -> AssociateResourceShareResponseTypeDef:
         """
-        Associates the specified resource share with the specified principals and
-        resources.
+        Adds the specified list of principals and list of resources to a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.associate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share)
         """
 
@@ -151,9 +153,10 @@ class RAMClient(BaseClient):
         permissionVersion: int = ...
     ) -> AssociateResourceSharePermissionResponseTypeDef:
         """
-        Associates a permission with a resource share.
+        Adds or replaces the RAM permission for a resource type included in a resource
+        share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share_permission)
         """
 
@@ -161,7 +164,7 @@ class RAMClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#can_paginate)
         """
 
@@ -179,7 +182,7 @@ class RAMClient(BaseClient):
         """
         Creates a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.create_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#create_resource_share)
         """
 
@@ -189,7 +192,7 @@ class RAMClient(BaseClient):
         """
         Deletes the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.delete_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#delete_resource_share)
         """
 
@@ -205,7 +208,7 @@ class RAMClient(BaseClient):
         Disassociates the specified principals or resources from the specified resource
         share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.disassociate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share)
         """
 
@@ -215,7 +218,7 @@ class RAMClient(BaseClient):
         """
         Disassociates an RAM permission from a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share_permission)
         """
 
@@ -225,7 +228,7 @@ class RAMClient(BaseClient):
         """
         Enables resource sharing within your organization in Organizations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#enable_sharing_with_aws_organization)
         """
 
@@ -239,7 +242,7 @@ class RAMClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#generate_presigned_url)
         """
 
@@ -249,7 +252,7 @@ class RAMClient(BaseClient):
         """
         Gets the contents of an RAM permission in JSON format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.get_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.get_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_permission)
         """
 
@@ -262,9 +265,10 @@ class RAMClient(BaseClient):
         maxResults: int = ...
     ) -> GetResourcePoliciesResponseTypeDef:
         """
-        Gets the policies for the specified resources that you own and have shared.
+        Retrieves the resource policies for the specified resources that you own and
+        have shared.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.get_resource_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_policies)
         """
 
@@ -280,9 +284,10 @@ class RAMClient(BaseClient):
         maxResults: int = ...
     ) -> GetResourceShareAssociationsResponseTypeDef:
         """
-        Gets the resources or principals for the resource shares that you own.
+        Retrieves the resource and principal associations for resource shares that you
+        own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.get_resource_share_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_associations)
         """
 
@@ -295,9 +300,9 @@ class RAMClient(BaseClient):
         maxResults: int = ...
     ) -> GetResourceShareInvitationsResponseTypeDef:
         """
-        Gets the invitations that you have received for resource shares.
+        Retrieves details about invitations that you have received for resource shares.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_invitations)
         """
 
@@ -314,31 +319,47 @@ class RAMClient(BaseClient):
         permissionArn: str = ...
     ) -> GetResourceSharesResponseTypeDef:
         """
-        Gets the resource shares that you own or the resource shares that are shared
-        with you.
+        Retrieves details about the resource shares that you own or that are shared with
+        you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.get_resource_shares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_shares)
         """
 
     def list_pending_invitation_resources(
-        self, *, resourceShareInvitationArn: str, nextToken: str = ..., maxResults: int = ...
+        self,
+        *,
+        resourceShareInvitationArn: str,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        resourceRegionScope: ResourceRegionScopeFilterType = ...
     ) -> ListPendingInvitationResourcesResponseTypeDef:
         """
-        Lists the resources in a resource share that is shared with you but that the
-        invitation is still pending for.
+        Lists the resources in a resource share that is shared with you but for which
+        the invitation is still `PENDING`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_pending_invitation_resources)
         """
 
+    def list_permission_versions(
+        self, *, permissionArn: str, nextToken: str = ..., maxResults: int = ...
+    ) -> ListPermissionVersionsResponseTypeDef:
+        """
+        Lists the available versions of the specified RAM permission.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_permission_versions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_permission_versions)
+        """
+
     def list_permissions(
         self, *, resourceType: str = ..., nextToken: str = ..., maxResults: int = ...
     ) -> ListPermissionsResponseTypeDef:
         """
-        Lists the RAM permissions.
+        Retrieves a list of available RAM permissions that you can use for the supported
+        resource types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_permissions)
         """
 
@@ -354,10 +375,10 @@ class RAMClient(BaseClient):
         maxResults: int = ...
     ) -> ListPrincipalsResponseTypeDef:
         """
-        Lists the principals that you have shared resources with or that have shared
+        Lists the principals that you are sharing resources with or that are sharing
         resources with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_principals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_principals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_principals)
         """
 
@@ -367,17 +388,21 @@ class RAMClient(BaseClient):
         """
         Lists the RAM permissions that are associated with a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_share_permissions)
         """
 
     def list_resource_types(
-        self, *, nextToken: str = ..., maxResults: int = ...
+        self,
+        *,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        resourceRegionScope: ResourceRegionScopeFilterType = ...
     ) -> ListResourceTypesResponseTypeDef:
         """
-        Lists the shareable resource types supported by RAM.
+        Lists the resource types that can be shared by RAM.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_resource_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_resource_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_types)
         """
 
@@ -390,13 +415,14 @@ class RAMClient(BaseClient):
         resourceArns: Sequence[str] = ...,
         resourceShareArns: Sequence[str] = ...,
         nextToken: str = ...,
-        maxResults: int = ...
+        maxResults: int = ...,
+        resourceRegionScope: ResourceRegionScopeFilterType = ...
     ) -> ListResourcesResponseTypeDef:
         """
         Lists the resources that you added to a resource shares or the resources that
         are shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.list_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.list_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resources)
         """
 
@@ -404,11 +430,10 @@ class RAMClient(BaseClient):
         self, *, resourceShareArn: str
     ) -> PromoteResourceShareCreatedFromPolicyResponseTypeDef:
         """
-        Resource shares that were created by attaching a policy to a resource are
-        visible only to the resource share owner, and the resource share cannot be
-        modified in RAM.
+        When you attach a resource-based permission policy to a resource, it
+        automatically creates a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#promote_resource_share_created_from_policy)
         """
 
@@ -419,7 +444,7 @@ class RAMClient(BaseClient):
         Rejects an invitation to a resource share from another Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#reject_resource_share_invitation)
         """
 
@@ -427,17 +452,17 @@ class RAMClient(BaseClient):
         self, *, resourceShareArn: str, tags: Sequence["TagTypeDef"]
     ) -> Dict[str, Any]:
         """
-        Adds the specified tags to the specified resource share that you own.
+        Adds the specified tag keys and values to the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceShareArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
-        Removes the specified tags from the specified resource share that you own.
+        Removes the specified tag key and value pairs from the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#untag_resource)
         """
 
@@ -450,9 +475,9 @@ class RAMClient(BaseClient):
         clientToken: str = ...
     ) -> UpdateResourceShareResponseTypeDef:
         """
-        Updates the specified resource share that you own.
+        Modifies some of the properties of the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Client.update_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#update_resource_share)
         """
 
@@ -461,7 +486,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
@@ -470,7 +495,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
@@ -479,7 +504,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
@@ -488,20 +513,20 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.GetResourceShares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.ListPrincipals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/ram.html#RAM.Paginator.ListResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
