@@ -13,10 +13,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence
+from typing import Dict, List, Sequence
 
 from .literals import (
     ResourceOwnerType,
+    ResourceRegionScopeFilterType,
+    ResourceRegionScopeType,
     ResourceShareAssociationStatusType,
     ResourceShareAssociationTypeType,
     ResourceShareFeatureSetType,
@@ -59,6 +61,8 @@ __all__ = (
     "GetResourceSharesResponseTypeDef",
     "ListPendingInvitationResourcesRequestRequestTypeDef",
     "ListPendingInvitationResourcesResponseTypeDef",
+    "ListPermissionVersionsRequestRequestTypeDef",
+    "ListPermissionVersionsResponseTypeDef",
     "ListPermissionsRequestRequestTypeDef",
     "ListPermissionsResponseTypeDef",
     "ListPrincipalsRequestRequestTypeDef",
@@ -494,6 +498,7 @@ _OptionalListPendingInvitationResourcesRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
+        "resourceRegionScope": ResourceRegionScopeFilterType,
     },
     total=False,
 )
@@ -515,6 +520,38 @@ ListPendingInvitationResourcesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListPermissionVersionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListPermissionVersionsRequestRequestTypeDef",
+    {
+        "permissionArn": str,
+    },
+)
+_OptionalListPermissionVersionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListPermissionVersionsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListPermissionVersionsRequestRequestTypeDef(
+    _RequiredListPermissionVersionsRequestRequestTypeDef,
+    _OptionalListPermissionVersionsRequestRequestTypeDef,
+):
+    pass
+
+
+ListPermissionVersionsResponseTypeDef = TypedDict(
+    "ListPermissionVersionsResponseTypeDef",
+    {
+        "permissions": List["ResourceSharePermissionSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListPermissionsRequestRequestTypeDef = TypedDict(
     "ListPermissionsRequestRequestTypeDef",
     {
@@ -606,6 +643,7 @@ ListResourceTypesRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
+        "resourceRegionScope": ResourceRegionScopeFilterType,
     },
     total=False,
 )
@@ -634,6 +672,7 @@ _OptionalListResourcesRequestRequestTypeDef = TypedDict(
         "resourceShareArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
+        "resourceRegionScope": ResourceRegionScopeFilterType,
     },
     total=False,
 )
@@ -814,6 +853,7 @@ ResourceTypeDef = TypedDict(
         "statusMessage": str,
         "creationTime": datetime,
         "lastUpdatedTime": datetime,
+        "resourceRegionScope": ResourceRegionScopeType,
     },
     total=False,
 )
@@ -824,7 +864,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -834,6 +874,7 @@ ServiceNameAndResourceTypeTypeDef = TypedDict(
     {
         "resourceType": str,
         "serviceName": str,
+        "resourceRegionScope": ResourceRegionScopeType,
     },
     total=False,
 )
